Skip to contentSkip to conversation

network/busy_poll: make test results more stable

PATCH New Alexey Kodanev 2 participants 3 messages Jun 27, 2016 – Jun 29, 2016

lore
Share & tools
lore
#0 lore raw

PATCH 1/1 network/busy_poll: make test results more stable

Changing tcp network load from 'connect/request/response/close' to 'request/response'. Results will be more stable as we aren't closing/establishing tcp connection after 3 requests from client.

There're other tests that do such stress testing so such test-case won't be removed.

It'll also decrease test time by several times.

---
 testcases/network/busy_poll/busy_poll01.sh |    4 +++-
 testcases/network/busy_poll/busy_poll02.sh |    6 ++++++
 2 files changed, 9 insertions(+), 1 deletions(-)
testcases/network/busy_poll/busy_poll01.sh +3 -1
index ecb34d7..ffa344b 100755
@@ -21,9 +21,11 @@
 TST_TOTAL=1
 TCID="busy_poll01"
 
+# tst_netload() parameters
 clients_num=2
 client_requests=500000
-max_requests=3
+# num of requests after server closing connection
+max_requests=500000
 
 . test_net.sh
 
testcases/network/busy_poll/busy_poll02.sh +6 -0
index d4dd052..18dead5 100755
@@ -21,6 +21,12 @@
 TST_TOTAL=1
 TCID="busy_poll02"
 
+# tst_netload() parameters
+clients_num=2
+client_requests=500000
+# num of requests after server closing connection
+max_requests=500000
+
 . test_net.sh
 
 cleanup()
Signature · 1 line
1.7.1
#1 lore raw

PATCH 1/1 network/busy_poll: make test results more stable

----- Original Message -----

Quoted 10 lines

From: "Alexey Kodanev" <[email protected]>
To: [email protected]
Cc: "vasily isaenko" <[email protected]>
Sent: Monday, 27 June, 2016 6:30:57 PM
Subject: [LTP] [PATCH] network/busy_poll: make test results more stable

Changing tcp network load from 'connect/request/response/close' to 'request/response'. Results will be more stable as we aren't closing/establishing tcp connection after 3 requests from client.

Quoted 6 lines

There're other tests that do such stress testing so such test-case won't be removed.

It'll also decrease test time by several times.

ACK.

As advertised my KVM guest running 4.5.0 shows more significant difference between busy poll 0/50:

Without patch:
busy_poll01 1 TINFO : set low latency busy poll to 50 busy_poll01 1 TINFO : run tcp_fastopen with 'localhost', port '37532' busy_poll01 1 TINFO : time spent is '25039' ms
busy_poll01 1 TINFO : set low latency busy poll to 0 busy_poll01 1 TINFO : run tcp_fastopen with 'localhost', port '61133' busy_poll01 1 TINFO : time spent is '35203' ms
busy_poll01 1 TPASS : busy poll increased performance by '29' %

real    1m2.866s
user    0m1.542s
sys     1m5.937s

With patch:
busy_poll01 1 TINFO : set low latency busy poll to 50 busy_poll01 1 TINFO : run tcp_fastopen with 'localhost', port '30109' busy_poll01 1 TINFO : time spent is '3874' ms
busy_poll01 1 TINFO : set low latency busy poll to 0 busy_poll01 1 TINFO : run tcp_fastopen with 'localhost', port '10440' busy_poll01 1 TINFO : time spent is '12561' ms
busy_poll01 1 TPASS : busy poll increased performance by '70' %

real    0m19.006s
user    0m0.749s
sys     0m16.408s
#2 lore raw

PATCH 1/1 network/busy_poll: make test results more stable

Hi,

Quoted 10 lines · Jan Stancek

...
With patch:
busy_poll01 1 TINFO : set low latency busy poll to 50 busy_poll01 1 TINFO : run tcp_fastopen with 'localhost', port '30109' busy_poll01 1 TINFO : time spent is '3874' ms
busy_poll01 1 TINFO : set low latency busy poll to 0 busy_poll01 1 TINFO : run tcp_fastopen with 'localhost', port '10440' busy_poll01 1 TINFO : time spent is '12561' ms
busy_poll01 1 TPASS : busy poll increased performance by '70' %

Quoted 3 lines
real    0m19.006s
user    0m0.749s
sys     0m16.408s

Thank you for verifying it, patch applied.

Best regards,
Alexey